summaryrefslogtreecommitdiffstats
path: root/lib/kofficecore/KoPoint.h
diff options
context:
space:
mode:
Diffstat (limited to 'lib/kofficecore/KoPoint.h')
-rw-r--r--lib/kofficecore/KoPoint.h24
1 files changed, 12 insertions, 12 deletions
diff --git a/lib/kofficecore/KoPoint.h b/lib/kofficecore/KoPoint.h
index 5f39e6c6..a5251638 100644
--- a/lib/kofficecore/KoPoint.h
+++ b/lib/kofficecore/KoPoint.h
@@ -20,23 +20,23 @@
#ifndef koPoint_h
#define koPoint_h
-#include <qwmatrix.h>
+#include <tqwmatrix.h>
#include <math.h>
/**
* A point whose coordinates are floating-point values ( "double"s ).
* The API isn't documented, it's a perfect mirror of QPoint.
*/
class KoPoint {
public:
KoPoint() { m_x = 0; m_y = 0; }
KoPoint(const double &x, const double &y) : m_x(x), m_y(y) {}
- explicit KoPoint(const QPoint & p) : m_x(p.x()), m_y(p.y()) {}
+ explicit KoPoint(const TQPoint & p) : m_x(p.x()), m_y(p.y()) {}
~KoPoint() {}
- bool operator==(const KoPoint &rhs) const { return QABS(m_x-rhs.x()) < 1E-10 && QABS(m_y-rhs.y()) < 1E-10; }
- bool operator!=(const KoPoint &rhs) const { return QABS(m_x-rhs.x()) > 1E-10 || QABS(m_y-rhs.y()) > 1E-10; }
+ bool operator==(const KoPoint &rhs) const { return TQABS(m_x-rhs.x()) < 1E-10 && TQABS(m_y-rhs.y()) < 1E-10; }
+ bool operator!=(const KoPoint &rhs) const { return TQABS(m_x-rhs.x()) > 1E-10 || TQABS(m_y-rhs.y()) > 1E-10; }
bool isNull() const { return m_x == 0 && m_y == 0; }
@@ -59,9 +59,9 @@ public:
friend inline KoPoint operator*( const double &, const KoPoint & );
friend inline double operator*( const KoPoint &a, const KoPoint &b );
- // Not in QPoint:
+ // Not in TQPoint:
void setCoords(const double &x, const double &y) { m_x = x; m_y = y; }
- KoPoint transform (const QWMatrix &m) const
+ KoPoint transform (const TQWMatrix &m) const
{
double x, y;
m.map(m_x, m_y, &x, &y);
@@ -80,13 +80,13 @@ public:
double manhattanLength() const
{
- return QABS( m_x ) + QABS( m_y );
+ return TQABS( m_x ) + TQABS( m_y );
}
- /// Convert to a QPoint - with precision loss!
- QPoint toQPoint() const
+ /// Convert to a TQPoint - with precision loss!
+ TQPoint toTQPoint() const
{
- return QPoint( qRound( m_x ), qRound( m_y ) );
+ return TQPoint( tqRound( m_x ), tqRound( m_y ) );
}
private:
@@ -115,7 +115,7 @@ inline double operator*( const KoPoint &a, const KoPoint &b )
#include <kdebug.h>
/** Show a floating point value with great precision (use within kdDebug) */
-#define DEBUGDOUBLE(d) QString::number( (d), 'g', 20 )
+#define DEBUGDOUBLE(d) TQString::number( (d), 'g', 20 )
inline kdbgstream operator<<( kdbgstream str, const KoPoint & r ) {
// should this use DEBUGDOUBLE?
@@ -20,23 +20,23 @@
/**
* A point whose coordinates are floating-point values ( "double"s ).
- * The API isn't documented, it's a perfect mirror of QPoint.
+ * The API isn't documented, it's a perfect mirror of TQPoint.
*/
class KoPoint {